using System;
using System.Collections.Generic;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.ComponentModel;
using System.Diagnostics;
using Infragistics.Windows.DataPresenter;
using System.Collections;

namespace CollectionViewInfragistics.InfragisticsExtension
{
    /// <summary>
    /// Interaction logic for AutoFilterPresenter.xaml
    /// </summary>

    public partial class AutoFilterPresenter : System.Windows.Controls.UserControl
    {

        private PropertyDescriptor _propertyDescriptor;
      
        private static ItemCollectionView _view;
        private static ItemCollection _collection;
        private static PropertyDescriptorCollection _pdCollection;

        public AutoFilterPresenter()
        {
            InitializeComponent();

            cmbFilter.DropDownOpened += new EventHandler(OnDropDownOpened);
            cmbFilter.SelectionChanged += new SelectionChangedEventHandler(OnFilterSelectionChanged);
        }

        void OnFilterSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (cmbFilter.SelectedIndex == 0)
            {
                _view.RemovePropertyFilter(_propertyDescriptor);
            }
            else
            {
                _view.AddPropertyFilter(_propertyDescriptor, cmbFilter.SelectedValue);
            }
        }

        void OnDropDownOpened(object sender, EventArgs e)
        {
          PopulateFilterData();
        }

        protected override void OnVisualParentChanged(DependencyObject oldParent)
        {
            base.OnVisualParentChanged(oldParent);
            Debug.WriteLine("OnLoaded");

            Infragistics.Windows.DataPresenter.LabelPresenter labelPresenter = (Infragistics.Windows.DataPresenter.LabelPresenter)VisualTreeHelper.GetParent(this);
            columnName.Text = labelPresenter.Field.Name;

            if (_view == null)
            {
                _view = (((labelPresenter.DataContext as FieldLayout).DataPresenter as XamDataGrid).DataSource as ItemCollectionView);
                _collection = _view.SourceCollection as ItemCollection;
                _pdCollection = TypeDescriptor.GetProperties(typeof(Item));
            }

            foreach (PropertyDescriptor propertyDescriptor in _pdCollection)
            {
                Debug.WriteLine(propertyDescriptor.Name + " == " + labelPresenter.Field.Name);
                if (propertyDescriptor.Name == labelPresenter.Field.Name)
                {
                    _propertyDescriptor = propertyDescriptor;
                    break;
                }
            }
        }

        private void PopulateFilterData()
        {
            if (_propertyDescriptor != null)
            {
                Hashtable distinctValues = new Hashtable();
                
                cmbFilter.Items.Clear();
                cmbFilter.Items.Add("<All>");
                ItemCollection collection = _view.SourceCollection as ItemCollection;

                foreach (Item item in collection)
                {
                    object obj = _propertyDescriptor.GetValue(item);
                    if (!distinctValues.ContainsKey(obj))
                    {
                        cmbFilter.Items.Add(obj);
                        distinctValues[obj] = 1;
                    }
                    else
                    {
                        distinctValues[obj] = ((int)distinctValues[obj]) + 1;
                    }
                }
            }
        }
    }
}