using System;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel;

namespace CollectionViewInfragistics
{
    class Item : INotifyPropertyChanged
    {
        #region Members

        private object _dummy = false;
        private decimal _value;

        #endregion

        #region Properties

        public decimal Value
        {
            get
            {
                return _value;
            }
            set
            {
                if (_value != value)
                {
                    _value = value;
                    RaisePropertyChangedEvent("Value");
                }
            }
        }
        #endregion

        #region INotifyPropertyChanged Members

        private PropertyChangedEventHandler _propertyChangedEventHandler;

        public event PropertyChangedEventHandler PropertyChanged
        {
            add
            {
                lock (_dummy)
                {
                    _propertyChangedEventHandler += value;
                }
            }
            remove
            {
                lock (_dummy)
                {
                    _propertyChangedEventHandler -= value;
                }
            }
        }

        private void RaisePropertyChangedEvent(string propertyName)
        {
            if (string.IsNullOrEmpty(propertyName))
            {
                throw new ArgumentNullException("propertyName");
            }

            PropertyChangedEventHandler propertyChangedEventHandler;
            lock (_dummy)
            {
                propertyChangedEventHandler = _propertyChangedEventHandler;
            }

            if (null != propertyChangedEventHandler)
            {
                propertyChangedEventHandler(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion
    }
}
